@@ -9,6 +9,8 @@ from queue import PriorityQueue
 import heapq
 import attrs
 
+import inspect
+
 import sys
 import ruamel.yaml
 
@@ -115,6 +117,11 @@ class NutContainerDefinitions:
 @dataclass
 class NutDatabaseInfo:
     db_name:str
+    
+@dataclass
+class ExternalAttribute:
+    module:str
+    attribute:str
      
 @dataclass
 class NutStructure:
@@ -125,6 +132,7 @@ class NutStructure:
     #db_name:str = field(init=False)
     nut_container_declarations:List[NutDeclaration]
     nut_containers:List[str] = field(init=False)
+    external_imports:List[ExternalAttribute]
     
     nut_main_struct:NutContainer    
     #nut_containers_list:List[NutContainer]
@@ -150,13 +158,16 @@ class GenericAttribute():
 
 class ValuePacket(GenericAttribute):
       
-    def __init__(self, name:str, value:Any, parent:str, type:Any) -> None:
+    def __init__(self, name:str, value:Any, parent:str, this_type:Any) -> None:
         super().__init__(atr_class=AtrClass.CHILD,
-                         atr_type=type,
+                         atr_type=this_type,
                          attribute=name)
         self._parent:str = parent
         self._value:Any = value
-        self._address_list:List[str] = []  
+        self._address_list:List[str] = []
+        its_a_class = hasattr(value, '__dict__')
+        self._is_class:bool = its_a_class
+         
         # self._value_type: Any = None
         
     @property
@@ -173,7 +184,11 @@ class ValuePacket(GenericAttribute):
         
     @property
     def address_list(self):
-        return self._address_list 
+        return self._address_list
+    
+    @property
+    def is_class(self):
+        return self._is_class
     
     address_list:List[str]
     
@@ -206,5 +221,9 @@ class ListOfThings:
     value_def:NutObjectType
     value:list
 
+@dataclass
+class Class:
+    value: Any 
+
 
 
