@@ -17,7 +17,8 @@ from data_squirrel.config.dynamic_data_nut import (
 class Nut_Attributes(Enum):
 	PrimaryStructure = "primary_structure_db"
 	Ensemble = "ensemble_db"
-	PrimaryStructureLists = "primary_structure_lists_db"
+	Sara2secStructLists = "primary_structure_lists_db"
+	SecondStuff = "secondary_structure_stuff_db"
 
 
 class NupackStrand(Nut):
@@ -135,6 +136,10 @@ class NupackStrand(Nut):
 			atr_type=str))
 
 		self.primary_structure_lists_db.new_attr(GenericAttribute(atr_class=AtrClass.CHILD,
-			attribute="primary_list_db",
-			atr_type=['PrimaryStructure', 'CLASS']))
+			attribute="sara2_struct_list_db",
+			atr_type=['Sara2SecondaryStructure', 'CLASS']))
+
+		self.secondary_structure_stuff_db.new_attr(GenericAttribute(atr_class=AtrClass.CHILD,
+			attribute="secondary_structure_db",
+			atr_type=Sara2SecondaryStructure))
 
